package WebGUI::i18n::Spanish::Asset_Collaboration;
use utf8;
our $I18N = {
  'Link Description' => {
    'lastUpdated' => '1252462253',
    'message' => 'Descripción del Enlace'
  },
  'Link URL' => {
    'lastUpdated' => '1252462262',
    'message' => 'URL del Enlace'
  },
  'List All Links' => {
    'lastUpdated' => '1252462272',
    'message' => 'Listar todos los Enlaces'
  },
  'Unsubscribe from %s' => {
    'lastUpdated' => '1276808634',
    'message' => 'Desuscribir de %s'
  },
  'You have been unsubscribed' => {
    'lastUpdated' => '1276808668',
    'message' => 'Ha sido desuscrito'
  },
  'add' => {
    'lastUpdated' => '1252463326',
    'message' => 'Agregar'
  },
  'add.label' => {
    'lastUpdated' => '1190390731',
    'message' => 'La palabra "agregar"'
  },
  'add.url' => {
    'lastUpdated' => '1190390747',
    'message' => 'Un URL para agregar un nuevo tema.'
  },
  'addlink' => {
    'lastUpdated' => '1190391021',
    'message' => 'Agregar un enlace'
  },
  'addlink.label' => {
    'lastUpdated' => '1190391298',
    'message' => 'La frase "agregar un enlace".'
  },
  'addquestion' => {
    'lastUpdated' => '1190391334',
    'message' => 'Hacer una pregunta'
  },
  'addquestion.label' => {
    'lastUpdated' => '1190391379',
    'message' => 'La frase "hacer una pregunta".'
  },
  'allow replies' => {
    'lastUpdated' => '1190391404',
    'message' => 'Permitir respuestas'
  },
  'allow replies description' => {
    'lastUpdated' => '1190391513',
    'message' => 'Seleccione "No" para evitar que haya respuestas a este aporte.'
  },
  'answer' => {
    'lastUpdated' => '1212584417',
    'message' => 'Responder'
  },
  'answer.label' => {
    'lastUpdated' => '1190391550',
    'message' => 'La palabra "Responder"'
  },
  'approval workflow' => {
    'lastUpdated' => '1252462330',
    'message' => '¿Cómo aprobar un mensaje?'
  },
  'approval workflow description' => {
    'lastUpdated' => '1252462360',
    'message' => 'Escoger el flujo de trabajo a aplicar a cada Publicación enviada.'
  },
  'archive' => {
    'lastUpdated' => '1190390765',
    'message' => 'Archivo'
  },
  'archive after' => {
    'lastUpdated' => '1252462719',
    'message' => 'Archivar después de'
  },
  'archive after description' => {
    'lastUpdated' => '1252462967',
    'message' => 'El tiempo después de la última actualización en el cual una Publicación se archivará, incluyendo su hilo completo de discusión, si existe.'
  },
  'ascending' => {
    'lastUpdated' => '1252463409',
    'message' => 'Ascendente'
  },
  'asset not committed' => {
    'lastUpdated' => '1223498842',
    'message' => '<p>Error.</p><p>Debe confirmar definitivamente este sistema de trabajo colaborativo antes de poder iniciar hilos de discusi&oacute;n.&nbsp;</p>'
  },
  'assetName' => {
    'lastUpdated' => '1199914063',
    'message' => 'Sistema de Colaboraci&oacute;n'
  },
  'attachment' => {
    'lastUpdated' => '1252462387',
    'message' => 'Archivo Adjunto'
  },
  'attachment.label' => {
    'lastUpdated' => '1252462399',
    'message' => 'La palabra "Adjunto"'
  },
  'attachment.length' => {
    'lastUpdated' => '1252462416',
    'message' => 'El tamaño de este adjunto en bytes'
  },
  'attachment.path' => {
    'lastUpdated' => '1207717940',
    'message' => 'La ruta en el sistema de archivos para este adjunto'
  },
  'attachment.url' => {
    'lastUpdated' => '1252463439',
    'message' => 'URL del adjunto'
  },
  'attachmentLoop' => {
    'lastUpdated' => '1207718016',
    'message' => 'El ciclo que contiene todos los adjuntos para este item'
  },
  'attachment_thumbnail' => {
    'lastUpdated' => '1207718113',
    'message' => 'La URL del thumbnail para este adjunto. Archivos que se representarn por un icono depende del tipo. Las imagenes tentran un verdadero thumbnail'
  },
  'attachments/post' => {
    'lastUpdated' => '1252462442',
    'message' => 'Adjuntos por Mensaje'
  },
  'attachments/post description' => {
    'lastUpdated' => '1252463458',
    'message' => '¿Cuantos adjuntos pueden agregarse por mensaje?'
  },
  'author' => {
    'lastUpdated' => '1252462461',
    'message' => 'El nombre de usuario que envio el Mensaje (post).'
  },
  'auto subscribe to thread' => {
    'lastUpdated' => '1252463477',
    'message' => '¿Suscribirse al hilo?'
  },
  'auto subscribe to thread help' => {
    'lastUpdated' => '1252463605',
    'message' => 'Si el usuario no está suscrito al hilo particular ni al Sistema de Colaboración, pero envían un mensaje al Sistema de Colaboración usando correo electrónico, este parámetro establece si quedarán suscritos al hilo o no. Esto funcionará solamente si la opción&nbsp; "¿Es obligatorio suscribirse para poder enviar por correo?" ha sido definida en "no".'
  },
  'avatar.url' => {
    'lastUpdated' => '1208122744',
    'message' => 'Una URL al avatar para el propietario de la publicaci&oacute;n, si los avatares est&aacute;n activados y el usuario tiene un avatar.'
  },
  'back' => {
    'lastUpdated' => '1212585380',
    'message' => 'Volver'
  },
  'back.label' => {
    'lastUpdated' => '1208122797',
    'message' => 'La palabra &quot;Volver&quot;'
  },
  'back.url' => {
    'lastUpdated' => '1208122897',
    'message' => 'Una URL para regresar a la vista principal de este sistema de colaboraci&oacute;n de Activos.'
  },
  'body' => {
    'lastUpdated' => '1190391701',
    'message' => 'Cuerpo'
  },
  'body.label' => {
    'lastUpdated' => '1208122967',
    'message' => 'La palabra &quot;Cuerpo&quot;'
  },
  'by' => {
    'lastUpdated' => '1190391255',
    'message' => 'por'
  },
  'by.label' => {
    'lastUpdated' => '1207709216',
    'message' => 'La palabra &quot;Por&quot;.'
  },
  'captcha label' => {
    'lastUpdated' => '1252463721',
    'message' => '¿Qué dice la imagen?'
  },
  'captcha_label' => {
    'lastUpdated' => '1257423395',
    'message' => 'La palabra "Captcha"'
  },
  'close' => {
    'lastUpdated' => '1190391713',
    'message' => 'Cerrar'
  },
  'close.label' => {
    'lastUpdated' => '1208123015',
    'message' => 'La palabra &quot;Cerrado&quot;'
  },
  'closed' => {
    'lastUpdated' => '1190391811',
    'message' => 'Cerrado'
  },
  'closed.label' => {
    'lastUpdated' => '1208123042',
    'message' => 'La palabra &quot;Cerrado&quot;'
  },
  'collab link' => {
    'lastUpdated' => '1190391883',
    'message' => 'El URL hacia la colaboración.'
  },
  'collaboration post list template variables title' => {
    'lastUpdated' => '1208180577',
    'message' => 'Variable para la publicaci&oacute;n de listas en el sistema colaborativo'
  },
  'collaboration rss template title' => {
    'lastUpdated' => '1208180678',
    'message' => 'Plantillas variables para el sistema colaborativo RSS'
  },
  'collaboration search template title' => {
    'lastUpdated' => '1208180872',
    'message' => 'Variables para la plantilla del sistema colaborativo de b&uacute;squeda'
  },
  'collaboration template labels title' => {
    'lastUpdated' => '1208180931',
    'message' => 'Etiquetas variables para el sistema colaborativo'
  },
  'collaboration template title' => {
    'lastUpdated' => '1208180954',
    'message' => 'Variables sistema colaborativo'
  },
  'collaboration unsubscribe template title' => {
    'lastUpdated' => '1276808692',
    'message' => 'Plantilla para Desuscripción de Sistemas de Colaboración'
  },
  'collaborationAssetId' => {
    'lastUpdated' => '1208181173',
    'message' => 'El &quot;assetId&quot; de este sistema de colaboraci&oacute;n. A diferencia de la variable &quot;assetId&quot; ,&nbsp; no ser&aacute; anulado por el &quot;assetIds&quot; dentro de los cadena o Publicaci&oacute;n.'
  },
  'compensation' => {
    'lastUpdated' => '1190391913',
    'message' => 'Compensación'
  },
  'compensation.label' => {
    'lastUpdated' => '1208181216',
    'message' => 'La palabra &quot;Compensaci&oacute;n&quot;'
  },
  'content' => {
    'lastUpdated' => '1190390981',
    'message' => 'El contenido formateado de este aporte.'
  },
  'content filter' => {
    'lastUpdated' => '1252463756',
    'message' => '¿Usar filtro de contenido?'
  },
  'content filter description' => {
    'lastUpdated' => '1208181279',
    'message' => 'Seleccione &quot;Si&quot; para filtrar el contenido en cada publicaci&oacute;n con el sistema de sustituciones'
  },
  'contentType' => {
    'lastUpdated' => '1208181310',
    'message' => 'Tipo de contenido'
  },
  'controls' => {
    'lastUpdated' => '1190392066',
    'message' => 'Un juego de iconos de edición para eliminar o reordenar este aporte.'
  },
  'cosmetic' => {
    'lastUpdated' => '1208181343',
    'message' => 'Cosm&eacute;tica (erratas, problemas de formato)'
  },
  'cosmetic.label' => {
    'lastUpdated' => '1208181372',
    'message' => 'La palabra &quot;Cosm&eacute;tica (erratas, problemas de formato)&quot;.'
  },
  'critical' => {
    'lastUpdated' => '1208209918',
    'message' => 'Cr&iacute;tica (la mayor&iacute;a no funciona)'
  },
  'critical.label' => {
    'lastUpdated' => '1208210031',
    'message' => 'La palabra &quot;Cr&iacute;tica (la mayor&iacute;a no funciona)&quot;.'
  },
  'date' => {
    'lastUpdated' => '1252463813',
    'message' => 'Fecha'
  },
  'date posted' => {
    'lastUpdated' => '1252463824',
    'message' => 'Publicado el'
  },
  'date submitted' => {
    'lastUpdated' => '1252463834',
    'message' => 'Enviado el'
  },
  'date updated' => {
    'lastUpdated' => '1252463842',
    'message' => 'Actualizado el'
  },
  'date.label' => {
    'lastUpdated' => '1208181505',
    'message' => 'La Palabra &quot;Fecha&quot;.'
  },
  'dateSubmitted.human' => {
    'lastUpdated' => '1252463870',
    'message' => 'La fecha en que el mensaje fue enviado, en formato legible para un humano.'
  },
  'dateUpdated.human' => {
    'lastUpdated' => '1252463889',
    'message' => 'La fecha de última actualización de esta publicación, en formato legible para un humano.'
  },
  'default karma scale' => {
    'lastUpdated' => '1252463925',
    'message' => 'Escala de Karma'
  },
  'default karma scale help' => {
    'lastUpdated' => '1252463936',
    'message' => 'Este es el valor por defecto que se le asignará a la escala Karma sobre el campo en el cadena. La escala Karma es un mecanismo de medida para la clasificación Karma que se pueden utilizar para desventajas, dificultades, etc'
  },
  'delete' => {
    'lastUpdated' => '1207727825',
    'message' => 'Eliminar'
  },
  'delete.label' => {
    'lastUpdated' => '1207727846',
    'message' => 'La palabra "eliminar"'
  },
  'descending' => {
    'lastUpdated' => '1208190518',
    'message' => 'Descendente'
  },
  'description' => {
    'lastUpdated' => '1208193000',
    'message' => 'Descripci&oacute;n'
  },
  'description.label' => {
    'lastUpdated' => '1208193105',
    'message' => 'La palabra &quot;Descripci&oacute;n&quot;.'
  },
  'display last reply' => {
    'lastUpdated' => '1252463951',
    'message' => '¿Mostrar última respuesta?'
  },
  'display last reply description' => {
    'lastUpdated' => '1252463988',
    'message' => 'Al seleccionar "Si", las plantillas recibirán variables adicionales que permitirán mostrar la última respuesta del hilo.'
  },
  'displayLastReply' => {
    'lastUpdated' => '1252464064',
    'message' => 'Un condicional que indica si el Sistema de Colaboración ha sido configurado para mostrar la última respuesta o no. Cuando esta variable es cierta, en la plantilla para el Sistema de Colaboración estarán disponibles las variables <strong>lastReply.*</strong>'
  },
  'docs' => {
    'lastUpdated' => '1252464088',
    'message' => 'URL a la documentación sobre el formato de este archivo, RSS 2.0 (campo opcional)'
  },
  'doit' => {
    'lastUpdated' => '1257423421',
    'message' => 'Un condicional que indica si se ha solicitado una búsqueda o no.'
  },
  'edit' => {
    'lastUpdated' => '1252464096',
    'message' => 'Editar'
  },
  'edit job' => {
    'lastUpdated' => '1252464107',
    'message' => 'Editar Oferta de Empleo'
  },
  'edit link' => {
    'lastUpdated' => '1252464114',
    'message' => 'Editar Enlace'
  },
  'edit message' => {
    'lastUpdated' => '1252464123',
    'message' => 'Editar Mensaje'
  },
  'edit question' => {
    'lastUpdated' => '1252464132',
    'message' => 'Editar Pregunta'
  },
  'edit stamp' => {
    'lastUpdated' => '1252464156',
    'message' => '¿Agregar fecha de edición a las publicaciones?'
  },
  'edit stamp description' => {
    'lastUpdated' => '1252464183',
    'message' => 'Indique si desea agregar la fecha de última edición a cada publicación.'
  },
  'edit submission' => {
    'lastUpdated' => '1252464193',
    'message' => 'Editar Publicación'
  },
  'edit timeout' => {
    'lastUpdated' => '1252464260',
    'message' => 'Tiempo Límite para Editar'
  },
  'edit timeout description' => {
    'lastUpdated' => '1252464241',
    'message' => 'Después que haya pasado este tiempo, la publicación ya no puede ser modificada por el autor original.'
  },
  'edit.label' => {
    'lastUpdated' => '1208206895',
    'message' => 'La palabra &quot;Editar&quot;'
  },
  'edit.url' => {
    'lastUpdated' => '1208207073',
    'message' => 'La URL para editar esta publicaci&oacute;n.'
  },
  'editForm archiveEnabled description' => {
    'lastUpdated' => '1215809250',
    'message' => 'Si la respuesta es S&iacute;, las publicaciones se ocultan autom&aacute;ticamente despu&eacute;s de un cierto intervalo'
  },
  'editForm archiveEnabled label' => {
    'lastUpdated' => '1252462679',
    'message' => '¿Archivar mensajes?'
  },
  'enable avatars' => {
    'lastUpdated' => '1252462992',
    'message' => '¿Habilitar Avatares?'
  },
  'enable avatars description' => {
    'lastUpdated' => '1252463083',
    'message' => 'Seleccione "Sí" para que los Avatares de los usuarios aparezcan en el Sistema de Colaboración. Es necesario que el campo Avatar este activado en el Perfil de Usuario, y los usuarios tendrán que subir un Avatar personal. <br> <br>El uso de Avatares reduce el desempeño de los Sistemas de Colaboración.'
  },
  'enable metadata' => {
    'lastUpdated' => '1252464287',
    'message' => '¿Habilitar metadatos en las Publicaciones?'
  },
  'enable metadata description' => {
    'lastUpdated' => '1208208541',
    'message' => 'Seleccione &quot;S&iacute;&quot; para permitir Publicaciones que tienen MetaDatos y pasivamente perfilados. Esto impactar&aacute; en el desempe&ntilde;o de la&nbsp; sistema de colaboraci&oacute;n. MetaDatos tambi&eacute;n debe estar habilitado a lo largo de la configuraci&oacute;n del sitio.'
  },
  'epochDate' => {
    'lastUpdated' => '1252464300',
    'message' => 'La fecha en que este item fue publicado como una época (número de segundos desde 1970-01-01), de manera que el macro Date pueda ser utilizado para darle formato especial.'
  },
  'every 10 minutes' => {
    'lastUpdated' => '1302868575',
    'message' => 'Cada 10 minutos'
  },
  'every 15 minutes' => {
    'lastUpdated' => '1302868581',
    'message' => 'Cada 15 minutos'
  },
  'every 20 minutes' => {
    'lastUpdated' => '1302868589',
    'message' => 'Cada 20 minutos'
  },
  'every 30 minutes' => {
    'lastUpdated' => '1302868594',
    'message' => 'Cada 30 minutos'
  },
  'every 5 minutes' => {
    'lastUpdated' => '1302868600',
    'message' => 'Cada 5 minutos'
  },
  'every hour' => {
    'lastUpdated' => '1302868605',
    'message' => 'Cada hora'
  },
  'every minute' => {
    'lastUpdated' => '1302868611',
    'message' => 'Cada minuto'
  },
  'every other hour' => {
    'lastUpdated' => '1302868621',
    'message' => 'Cada dos horas'
  },
  'every other minute' => {
    'lastUpdated' => '1302868627',
    'message' => 'Cada dos minutos'
  },
  'fatal' => {
    'lastUpdated' => '1252464307',
    'message' => 'Fatal (no puede continuar hasta que esto se resuelva).'
  },
  'fatal.label' => {
    'lastUpdated' => '1208208637',
    'message' => 'La palabra &quot;Fatal (no puede continuar hasta que se resuelva)&quot;.'
  },
  'feed description' => {
    'lastUpdated' => '1252464340',
    'message' => 'La descripcion de la Fuente RSS (se toma del resumen sumario del Sistema de Colaboración)'
  },
  'feed title' => {
    'lastUpdated' => '1252464363',
    'message' => 'El título de la Fuente RSS (se toma del Título del Sistema de Colaboración).'
  },
  'filter code' => {
    'lastUpdated' => '1252464383',
    'message' => 'Filtrar Código HTML'
  },
  'filter code description' => {
    'lastUpdated' => '1252464416',
    'message' => 'Determina el nivel de filtrado de código HTML aplicado sobre cada Publicación que inicia un hilo.'
  },
  'flatLayout' => {
    'lastUpdated' => '1252464423',
    'message' => 'Plano'
  },
  'form.footer' => {
    'lastUpdated' => '1257423514',
    'message' => 'HTML necesario para finalizar el formulario.'
  },
  'form.header' => {
    'lastUpdated' => '1257423480',
    'message' => 'HTML y JavaScript en el encabezado necesarios para el correcto funcionamiento del formulario.'
  },
  'form.search' => {
    'lastUpdated' => '1252464483',
    'message' => 'Un botón agregado al formulario para iniciar las búsquedas.'
  },
  'full text link' => {
    'lastUpdated' => '1252464505',
    'message' => 'URL hacia el texto completo del item.'
  },
  'generator' => {
    'lastUpdated' => '1252464537',
    'message' => 'El programa usado para generar la Fuente RSS, i.e. WebGUI más información de la versión particular (campo opcional).'
  },
  'get cs mail' => {
    'lastUpdated' => '1252464624',
    'message' => 'Recibir Publicaciones vía Correo'
  },
  'get mail' => {
    'lastUpdated' => '1252464635',
    'message' => '¿Recibir publicaciones por correo?'
  },
  'get mail help' => {
    'lastUpdated' => '1252464594',
    'message' => '¿Desea que este Sistema de Colaboración obtenga las publicaciones a partir de una cuenta de correo electrónico?'
  },
  'get mail interval' => {
    'lastUpdated' => '1252464645',
    'message' => 'Revisar el correo cada'
  },
  'get mail interval help' => {
    'lastUpdated' => '1252464656',
    'message' => '¿Con qué frecuencia hay que comprobar si hay correo en el servidor?'
  },
  'group to edit hoverhelp' => {
    'lastUpdated' => '1270050615',
    'message' => 'Grupo que puede Editar Publicaciones'
  },
  'group to edit label' => {
    'lastUpdated' => '1252464691',
    'message' => 'Grupo que puede Editar Publicaciones'
  },
  'guid' => {
    'lastUpdated' => '1208211922',
    'message' => 'Un identificador &uacute;nico para este tema'
  },
  'has posted to one of your subscriptions' => {
    'lastUpdated' => '1252464709',
    'message' => 'ha escrito en una de sus suscripciones'
  },
  'hideProfileUrl' => {
    'lastUpdated' => '1255725969',
    'message' => 'Un condicional que indice si el publicador o el usuario actual es un Visitante. En el primer caso, el Perfil de Usuario del Visitante no es visible a ningún usuario. En el segundo caso, el Visitante no puede ver el Perfil de Usuario de ningún usuario.'
  },
  'id' => {
    'lastUpdated' => '1208211979',
    'message' => 'El ID de el Activo de esta publicaci&oacute;n'
  },
  'image' => {
    'lastUpdated' => '1208212030',
    'message' => 'Imagen'
  },
  'image.label' => {
    'lastUpdated' => '1208212045',
    'message' => 'La palabra &quot;Imagen&quot;'
  },
  'image.url' => {
    'lastUpdated' => '1208212131',
    'message' => 'Si esta publicaci&oacute;n tiene archivos adjuntos, la URL de la primera imagen de archivo adjunto.'
  },
  'isFifth' => {
    'lastUpdated' => '1208212213',
    'message' => 'Un condicional que indica que es cierto, si esta publicaci&oacute;n es la quinta en esta colaboraci&oacute;n de Activos.'
  },
  'isFourth' => {
    'lastUpdated' => '1208212351',
    'message' => 'Un condicional que indica que es cierto, si esta publicaci&oacute;n es la cuarta de esta Colaboraci&oacute;n de Activos.'
  },
  'isSecond' => {
    'lastUpdated' => '1208212367',
    'message' => 'Un condicional que indica que es cierto, si esta publicaci&oacute;n es la segunda de esta Colaboraci&oacute;n de Activos.'
  },
  'isThird' => {
    'lastUpdated' => '1208212384',
    'message' => 'Un condicional que indica que es cierto, si esta publicaci&oacute;n es la tercera de esta Colaboraci&oacute;n de Activos.'
  },
  'item description' => {
    'lastUpdated' => '1208212413',
    'message' => 'Una sinopsis del tema.'
  },
  'item_loop' => {
    'lastUpdated' => '1208212546',
    'message' => 'Bucles sobre la publicaci&oacute;n que han de transmitirse de este feed RSS.'
  },
  'job description' => {
    'lastUpdated' => '1252464743',
    'message' => 'Descripción del Cargo'
  },
  'job requirements' => {
    'lastUpdated' => '1252464830',
    'message' => 'Requisitos del Cargo'
  },
  'job title' => {
    'lastUpdated' => '1252464771',
    'message' => 'Título del Cargo'
  },
  'job.description.label' => {
    'lastUpdated' => '1252464785',
    'message' => 'La frase "Descripción del Cargo"'
  },
  'job.header.label' => {
    'lastUpdated' => '1252464805',
    'message' => 'La frase "Editar&nbsp; Oferta de Trabajo"'
  },
  'job.requirements.label' => {
    'lastUpdated' => '1252464818',
    'message' => 'La frase "Requisitos del Cargo".'
  },
  'job.title.label' => {
    'lastUpdated' => '1252464842',
    'message' => 'La frase "Título del Cargo".'
  },
  'karma rank' => {
    'lastUpdated' => '1252464868',
    'message' => 'Orden por Karma'
  },
  'karma rating multiplier' => {
    'lastUpdated' => '1252464954',
    'message' => 'Karma otorgado al autor al ser evaluado'
  },
  'karma rating multiplier description' => {
    'lastUpdated' => '1252464943',
    'message' => 'Si el karma está habilitado en su sitio web, este será la cantidad de karma recibida por el autor original de la publicación cuando otro usuario califique la publicación.'
  },
  'karma scale' => {
    'lastUpdated' => '1252465013',
    'message' => 'Escala de Karma'
  },
  'karma spent to rate' => {
    'lastUpdated' => '1252465029',
    'message' => 'Karma Invertido en Calificar'
  },
  'karma spent to rate description' => {
    'lastUpdated' => '1252465111',
    'message' => 'Si el karma es habilitado en su sitio web, esta cantidad de carma se restará del usuario que emite la calificación de un artículo, como si se tratara de un costo por evaluar. La intención es impedir que los usuarios evalúen cualquier cosa sin considerar cuidadosamente la calificación que otorgan.'
  },
  'karma/post' => {
    'lastUpdated' => '1252465175',
    'message' => 'Karma por Publicación'
  },
  'karma/post description' => {
    'lastUpdated' => '1252465202',
    'message' => 'Si el Karma está habilitado en su sitio, la cantidad de Karma otorgada al usuario por cada Publicación.'
  },
  'karmaIsEnabled' => {
    'lastUpdated' => '1252465217',
    'message' => 'Un condicional que indica si el uso del karma está habilitado o no.'
  },
  'karmaRank.label' => {
    'lastUpdated' => '1257423547',
    'message' => 'La frase "Orden por Karma"'
  },
  'karmascale.label' => {
    'lastUpdated' => '1257423570',
    'message' => 'La frase "Escala de Karma"'
  },
  'keywords label' => {
    'lastUpdated' => '1252465272',
    'message' => 'Palabras Clave'
  },
  'keywords.label' => {
    'lastUpdated' => '1257423585',
    'message' => 'La frase "Palabras Clave"'
  },
  'lastBuildDate' => {
    'lastUpdated' => '1208269979',
    'message' => 'La fecha de este feed que se actualiz&oacute; por &uacute;ltima vez. (Campo opcional)'
  },
  'lastReply' => {
    'lastUpdated' => '1208270014',
    'message' => '&Uacute;ltima Respuesta'
  },
  'lastReply.dateSubmitted.human' => {
    'lastUpdated' => '1208270192',
    'message' => 'La fecha de la &uacute;ltima respuesta se present&oacute;, en un formato legible por humanos.'
  },
  'lastReply.hideProfileUrl' => {
    'lastUpdated' => '1255726019',
    'message' => 'Un condicional que indica si el publicador de la última respuesta o el usuario actual es un Visitante. En el primer caso, el Perfil de Usuario del Visitante no es visible a ningún usuario. En el segundo caso, el Visitante no tiene acceso al Perfil de Usuario de ningún usuario.'
  },
  'lastReply.label' => {
    'lastUpdated' => '1208270228',
    'message' => 'La frase &quot;&quot;&Uacute;ltima Respuesta&quot;.'
  },
  'lastReply.timeSubmitted.human' => {
    'lastUpdated' => '1208270278',
    'message' => 'La &uacute;ltima vez que la respuesta se present&oacute;, en un formato legible por humanos.'
  },
  'lastReply.title' => {
    'lastUpdated' => '1208270299',
    'message' => 'El t&iacute;tulo de la &uacute;ltima respuesta'
  },
  'lastReply.url' => {
    'lastUpdated' => '1208270331',
    'message' => 'La URL para la &uacute;ltima respuesta de esta publicaci&oacute;n'
  },
  'lastReply.user.isVisitor' => {
    'lastUpdated' => '1208270615',
    'message' => 'Un condicional que es verdadero si el publicandor de la &uacute;ltima respuesta es un visitante'
  },
  'lastReply.userProfile.url' => {
    'lastUpdated' => '1208270719',
    'message' => 'La URL en el perfil del usuario que env&iacute;a esta publicaci&oacute;n.'
  },
  'lastReply.username' => {
    'lastUpdated' => '1208270735',
    'message' => 'El nombre del usuario qui&eacute;n guardo la &uacute;ltima respuesta.'
  },
  'layout' => {
    'lastUpdated' => '1208270777',
    'message' => 'Layout'
  },
  'layout.flat.label' => {
    'lastUpdated' => '1208270806',
    'message' => 'La palabra &quot;Plano&quot;.'
  },
  'layout.label' => {
    'lastUpdated' => '1208270833',
    'message' => 'La palabra &quot;Layaout&quot;.'
  },
  'layout.nested.label' => {
    'lastUpdated' => '1208270878',
    'message' => 'La palabra &quot;Nested&quot;'
  },
  'link.header.label' => {
    'lastUpdated' => '1208272555',
    'message' => 'La frase &quot;Editar V&iacute;nculo&quot;'
  },
  'location' => {
    'lastUpdated' => '1252465324',
    'message' => 'Ubicación'
  },
  'location.label' => {
    'lastUpdated' => '1252465335',
    'message' => 'La palabra "Ubicación".'
  },
  'lock' => {
    'lastUpdated' => '1207726097',
    'message' => 'bloquear'
  },
  'lock.label' => {
    'lastUpdated' => '1208272823',
    'message' => 'La palabra&quot;Bloquear&quot;'
  },
  'mail' => {
    'lastUpdated' => '1252465351',
    'message' => 'Correo'
  },
  'mail account' => {
    'lastUpdated' => '1252465364',
    'message' => 'Cuenta'
  },
  'mail account help' => {
    'lastUpdated' => '1252465406',
    'message' => 'El nombre de usuario (sencillo o en forma de dirección de correo) necesario para conectarse al servidor de correo para descargar mensajes.'
  },
  'mail address' => {
    'lastUpdated' => '1252465429',
    'message' => 'Dirección'
  },
  'mail address help' => {
    'lastUpdated' => '1252465458',
    'message' => 'Dirección de correo electrónico a la cual los usuarios deben enviar sus mensajes para que sean publicados en el Sistema de Colaboración.'
  },
  'mail password' => {
    'lastUpdated' => '1252465470',
    'message' => 'Contraseña'
  },
  'mail password help' => {
    'lastUpdated' => '1252465513',
    'message' => 'La contraseña necesaria para acceder al buzón de mensajes en el servidor de correo.'
  },
  'mail prefix' => {
    'lastUpdated' => '1252465564',
    'message' => 'Prefijo del Asunto'
  },
  'mail prefix help' => {
    'lastUpdated' => '1252465552',
    'message' => 'Este texto será agregado al comienzo de la línea Asunto de los mensajes de correo emitidos por el Sistema de Colaboración.'
  },
  'mail server' => {
    'lastUpdated' => '1252465590',
    'message' => 'Servidor'
  },
  'mail server help' => {
    'lastUpdated' => '1252465615',
    'message' => 'Nombre o dirección IP del servidor de correo que aloja el buzón.'
  },
  'max image size' => {
    'lastUpdated' => '1252465704',
    'message' => 'Tamaño Máximo de Imagenes'
  },
  'max image size help' => {
    'lastUpdated' => '1252465805',
    'message' => 'Establece el tamaño de las imágenes adjuntas en el Sistema de Colaboración. Si se establece en 0, entonces se utilizará el tamaño definido en la Configuración principal de WebGUI. Por otro lado, si se cambia este parámetro sus efectos <strong>no</strong> son retroactivos, de modo que tendrá que volver a editar cada publicación para que las imágenes sean cambiadas de tamaño efectivamente.'
  },
  'message' => {
    'lastUpdated' => '1207727963',
    'message' => 'Mensaje'
  },
  'message.header.label' => {
    'lastUpdated' => '1208273782',
    'message' => 'La frase &quot;Editar Mensaje&quot;.'
  },
  'message.label' => {
    'lastUpdated' => '1208273771',
    'message' => 'La palabra &quot;Mensaje&quot;'
  },
  'minor' => {
    'lastUpdated' => '1252465856',
    'message' => 'Menor (molesto, pero inocuo)'
  },
  'minor.label' => {
    'lastUpdated' => '1208274036',
    'message' => 'La palabra &quot;Menor (la molestia, pero no causa da&ntilde;o)&quot;.'
  },
  'nested' => {
    'lastUpdated' => '1252465896',
    'message' => 'Anidado'
  },
  'new window' => {
    'lastUpdated' => '1252465906',
    'message' => '¿Abrir en una nueva ventana?'
  },
  'newWindow.label' => {
    'lastUpdated' => '1208274135',
    'message' => 'La palabra &quot;Abrir en una nueva ventana?&quot;.'
  },
  'next' => {
    'lastUpdated' => '1207727486',
    'message' => 'Siguiente'
  },
  'next.label' => {
    'lastUpdated' => '1207727930',
    'message' => 'La palabra "siguiente"'
  },
  'no user email error message' => {
    'lastUpdated' => '1276808717',
    'message' => 'No hay ningún usuario con esa dirección de correo.'
  },
  'notification template' => {
    'lastUpdated' => '1252466031',
    'message' => 'Sistema de Colaboración, Plantilla para Notificaciones'
  },
  'notification template description' => {
    'lastUpdated' => '1208274634',
    'message' => 'La plantilla utilizada para generar mensajes de correo electr&oacute;nico para los usuarios que se han suscrito a este Activo.'
  },
  'once per day' => {
    'lastUpdated' => '1302868639',
    'message' => 'Una vez al día'
  },
  'open' => {
    'lastUpdated' => '1208274669',
    'message' => 'Abrir'
  },
  'open.label' => {
    'lastUpdated' => '1208274689',
    'message' => 'La palabra &quot;Abrir&quot;'
  },
  'post' => {
    'lastUpdated' => '1252466385',
    'message' => 'Publicar'
  },
  'post received template' => {
    'lastUpdated' => '1252466705',
    'message' => 'Plantilla para Publicación Recibida'
  },
  'post received template hoverHelp' => {
    'lastUpdated' => '1223498995',
    'message' => 'La plantilla a utilizar para confirmar la recepci&oacute;n de los mensajes publicados por los usuarios.'
  },
  'post template' => {
    'lastUpdated' => '1252466728',
    'message' => 'Sistema de Colaboración, Plantilla para Publicación'
  },
  'post template description' => {
    'lastUpdated' => '1208274739',
    'message' => 'La plantilla para una publicaci&oacute;n individual.'
  },
  'post title' => {
    'lastUpdated' => '1252466774',
    'message' => 'El título de la publicación.'
  },
  'post.label' => {
    'lastUpdated' => '1208274760',
    'message' => 'La palabra &quot;Publicar&quot;.'
  },
  'post_loop' => {
    'lastUpdated' => '1208274857',
    'message' => 'Una lista de garant&iacute;a para esto activos publicados.'
  },
  'post_loop_user.isVisitor' => {
    'lastUpdated' => '1255726037',
    'message' => 'Un condicional que indica si el publicador es Visitante.'
  },
  'posts/page' => {
    'lastUpdated' => '1252466790',
    'message' => 'Publicaciones por Página'
  },
  'posts/page description' => {
    'lastUpdated' => '1252466803',
    'message' => 'El número de entradas que se muestran en cada una de las páginas en el hilo plantilla. Configurar este número muy alto puede frenar la generación de la página.'
  },
  'preview' => {
    'lastUpdated' => '1252466813',
    'message' => 'vista previa'
  },
  'previous' => {
    'lastUpdated' => '1207727776',
    'message' => 'Anterior'
  },
  'previous.label' => {
    'lastUpdated' => '1207727795',
    'message' => 'La palabra "anterior".'
  },
  'pubDate' => {
    'lastUpdated' => '1208275012',
    'message' => 'La fecha en que el tema se public&oacute;.'
  },
  'query.form' => {
    'lastUpdated' => '1208275081',
    'message' => 'HTML form for adding a field where all input has to be in matched pages.'
  },
  'question' => {
    'lastUpdated' => '1208275096',
    'message' => 'Pregunta'
  },
  'question.header.label' => {
    'lastUpdated' => '1208275128',
    'message' => 'La frase &quot;Editar Pregunta&quot;.'
  },
  'question.label' => {
    'lastUpdated' => '1208275143',
    'message' => 'La palabra &quot;Pregunta&quot;'
  },
  'rate' => {
    'lastUpdated' => '1207729425',
    'message' => 'Califique'
  },
  'rate.label' => {
    'lastUpdated' => '1252466895',
    'message' => 'La palabra "Califique"'
  },
  'rating' => {
    'lastUpdated' => '1207728095',
    'message' => 'Puntaje'
  },
  'rating.label' => {
    'lastUpdated' => '1208275205',
    'message' => 'La palabra &quot;Votado&quot;'
  },
  'rating_loop' => {
    'lastUpdated' => '1208275250',
    'message' => 'Un bucle que se ejecuta una vez por cada punto de votaci&oacute;n que el Servicio de Correos ha'
  },
  'rating_loop.count' => {
    'lastUpdated' => '1208275288',
    'message' => 'El &iacute;ndice de la variable rating_loop.'
  },
  'read more' => {
    'lastUpdated' => '1252466930',
    'message' => 'Leer más'
  },
  'readmore.label' => {
    'lastUpdated' => '1208275307',
    'message' => 'La frase &quot;Leer M&aacute;s&quot;'
  },
  'rejected' => {
    'lastUpdated' => '1252466977',
    'message' => 'Rechazado'
  },
  'rejected because no user account' => {
    'lastUpdated' => '1252467219',
    'message' => 'No se le permitió hacer una publicación por correo electrónico porque no pudimos encontrar su cuenta de usuario. Quizás Ud. empleó una dirección de correo diferente a la que está asociada a su cuenta de usuario.'
  },
  'rejected because not allowed' => {
    'lastUpdated' => '1252467279',
    'message' => 'No se le permitió hacer una publicación por correo electrónico porque
no cuenta con suficientes privilegios o bien no está suscrito a la discusión.'
  },
  'replies' => {
    'lastUpdated' => '1190390893',
    'message' => 'Respuestas'
  },
  'replies.label' => {
    'lastUpdated' => '1207718364',
    'message' => 'la palabra &quot;Respuestas&quot;'
  },
  'reply' => {
    'lastUpdated' => '1252463313',
    'message' => 'Responder'
  },
  'reply filter code' => {
    'lastUpdated' => '1252467301',
    'message' => 'Filtrar Código en Respuestas'
  },
  'reply filter code description' => {
    'lastUpdated' => '1252467323',
    'message' => 'Establece el nivel de filtrado de código HTML efectuado sobre las respuestas.'
  },
  'reply rich editor' => {
    'lastUpdated' => '1252467376',
    'message' => 'Editor para Respuestas'
  },
  'reply rich editor description' => {
    'lastUpdated' => '1252467410',
    'message' => 'Seleccione el tipo de Editor a emplear para la creación de respuestas.'
  },
  'reply.label' => {
    'lastUpdated' => '1207718345',
    'message' => 'La palabra &quot;responder&quot;'
  },
  'require subscription for email posting' => {
    'lastUpdated' => '1252467446',
    'message' => '¿Suscribirse es obligatorio para publicar por correo?'
  },
  'require subscription for email posting help' => {
    'lastUpdated' => '1208298376',
    'message' => 'Si esto se define en s&iacute;, entonces el usuario no s&oacute;lo tiene que estar en el grupo para publicar, sino que tambi&eacute;n debe estar suscrito al sistema de colaboraci&oacute;n o hilo con el fin de publicar en ella.'
  },
  'responses' => {
    'lastUpdated' => '1207728047',
    'message' => 'Respuestas'
  },
  'responses.label' => {
    'lastUpdated' => '1208298466',
    'message' => 'La palabra &quot;respuestas&quot;.'
  },
  'rich editor' => {
    'lastUpdated' => '1252467488',
    'message' => 'Editor Extendido'
  },
  'rich editor description' => {
    'lastUpdated' => '1208298550',
    'message' => 'Descripci&oacute;n del editor enrriquecido'
  },
  'rss template' => {
    'lastUpdated' => '1252467496',
    'message' => 'Sistema de Colaboración, Plantilla RSS'
  },
  'rss template description' => {
    'lastUpdated' => '1208298644',
    'message' => 'La plantilla utilizada para generar los xml de un feed rss de activos sobre la base de este.'
  },
  'rss.url' => {
    'lastUpdated' => '1208298776',
    'message' => 'Una URL para descargar el resumen de este RSS de Activos.'
  },
  'search' => {
    'lastUpdated' => '1208298816',
    'message' => 'Buscar'
  },
  'search template' => {
    'lastUpdated' => '1252467598',
    'message' => 'SIstema de colaboración, Plantilla para Búsquedas'
  },
  'search template description' => {
    'lastUpdated' => '1208298953',
    'message' => 'La plantilla para esta colaboraci&oacute;n de Activos el formulario de b&uacute;squeda y los resultados.'
  },
  'search.label' => {
    'lastUpdated' => '1208298972',
    'message' => 'La palabra &quot;B&uacute;scar&quot;'
  },
  'search.url' => {
    'lastUpdated' => '1208299052',
    'message' => 'Una URL para acceder a la b&uacute;squeda de activos para esta colaboraci&oacute;n.'
  },
  'sequence' => {
    'lastUpdated' => '1208299067',
    'message' => 'Secuencia'
  },
  'severity' => {
    'lastUpdated' => '1208299373',
    'message' => 'Severidad'
  },
  'severity.label' => {
    'lastUpdated' => '1208299424',
    'message' => 'La palabra &quot;Severidad&quot;.'
  },
  'sort by' => {
    'lastUpdated' => '1252467873',
    'message' => 'Ordenar por'
  },
  'sort by description' => {
    'lastUpdated' => '1276808724',
    'message' => 'Las publicaciones siempre se muestran ordenadas. Este campo permite especificar cuál propiedad utilizar para dicho orden. Pueden seleccionarse múltiples propiedades.'
  },
  'sort order' => {
    'lastUpdated' => '1252468160',
    'message' => 'Orden'
  },
  'sort order description' => {
    'lastUpdated' => '1208374771',
    'message' => 'Ordenar en orden ascendente o descendente.'
  },
  'sortby.date.url' => {
    'lastUpdated' => '1208375443',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones, por la fecha en que fueron presentadas.'
  },
  'sortby.karmaRank.url' => {
    'lastUpdated' => '1208375521',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones por la cantidad de usuarios Karma que han transferido al hilo.'
  },
  'sortby.lastreply.url' => {
    'lastUpdated' => '1208375725',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones por la fecha de la &uacute;ltima actualizaci&oacute;n.'
  },
  'sortby.rating.url' => {
    'lastUpdated' => '1208375841',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones por sus calificaciones.'
  },
  'sortby.replies.url' => {
    'lastUpdated' => '1208375917',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaicones por el n&uacute;mero de respuestas para la publicaci&oacute;n.'
  },
  'sortby.title.url' => {
    'lastUpdated' => '1208375961',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones por el t&iacute;tulo'
  },
  'sortby.username.url' => {
    'lastUpdated' => '1208376013',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones por nombre de usuario.'
  },
  'sortby.views.url' => {
    'lastUpdated' => '1208376426',
    'message' => 'Una URL para clasificar y mostrar la lista de las publicaciones por el n&uacute;mero de veces que cada uno ha sido le&iacute;do.'
  },
  'status' => {
    'lastUpdated' => '1252468242',
    'message' => 'Estado'
  },
  'status.label' => {
    'lastUpdated' => '1252468252',
    'message' => 'La palabra "Estado"'
  },
  'stick.label' => {
    'lastUpdated' => '1252468380',
    'message' => 'La frase "Hacer pegajoso"'
  },
  'sticky' => {
    'lastUpdated' => '1252468363',
    'message' => 'Hacer pegajoso'
  },
  'subject' => {
    'lastUpdated' => '1207719471',
    'message' => 'Asunto'
  },
  'subject.label' => {
    'lastUpdated' => '1208376558',
    'message' => 'La palabra &quot;Asunto&quot;.'
  },
  'submission.header.label' => {
    'lastUpdated' => '1208376593',
    'message' => 'La frase &quot;Editar Presentaci&oacute;n&quot;.'
  },
  'subscribe' => {
    'lastUpdated' => '1190390944',
    'message' => 'Suscribir'
  },
  'subscribe.label' => {
    'lastUpdated' => '1208376659',
    'message' => 'La palabra &quot;Suscribir&quot;'
  },
  'subscribe.url' => {
    'lastUpdated' => '1208377814',
    'message' => 'Una URL de suscripci&oacute;n que el usuario actual da a esta Colaboraci&oacute;n de Activos. Cuando un nuevo contenido se presenta a la Colaboraci&oacute;n de activos, el usuario ser&aacute; notificado.'
  },
  'subscription group hoverHelp' => {
    'lastUpdated' => '1252468418',
    'message' => 'Administrar usuarios en el grupo de suscritos a este Sistema de Colaboración.'
  },
  'subscription group label' => {
    'lastUpdated' => '1252468432',
    'message' => 'Grupo de Suscritos'
  },
  'synopsis' => {
    'lastUpdated' => '1207723272',
    'message' => 'Resumen'
  },
  'synopsis.label' => {
    'lastUpdated' => '1252468485',
    'message' => 'La palabra "Resumen"'
  },
  'system template' => {
    'lastUpdated' => '1252468506',
    'message' => 'Plantilla del Sistema de Colaboración'
  },
  'system template description' => {
    'lastUpdated' => '1252468528',
    'message' => 'Plantilla principal a utilizar en este Activo de Sistema de Colaboración.'
  },
  'thread approval workflow' => {
    'lastUpdated' => '1252468551',
    'message' => '¿Cómo aprobar respuestas al hilo?'
  },
  'thread approval workflow description' => {
    'lastUpdated' => '1208378957',
    'message' => 'Elige un flujo de trabajo a ser ejecutado en cada secuencia, ya que se ha presentado.'
  },
  'thread template' => {
    'lastUpdated' => '1252468568',
    'message' => 'Sistema de Colaboración, Plantilla para Hilos'
  },
  'thread template description' => {
    'lastUpdated' => '1208379387',
    'message' => 'La plantilla para mostrar una sentencia'
  },
  'threads/page' => {
    'lastUpdated' => '1252468589',
    'message' => 'Hilos por Página'
  },
  'threads/page description' => {
    'lastUpdated' => '1208443583',
    'message' => 'El n&uacute;mero de publicaciones que aparecen en cada p&aacute;gina en el sistema de plantilla. Configurar este n&uacute;mero muy alto puede frenar la generaci&oacute;n de la p&aacute;gina.'
  },
  'thumbnail' => {
    'lastUpdated' => '1252468601',
    'message' => 'Miniatura'
  },
  'thumbnail size' => {
    'lastUpdated' => '1252468616',
    'message' => 'Tamaño de la Miniatura'
  },
  'thumbnail size help' => {
    'lastUpdated' => '1252468623',
    'message' => 'Establezca el tamaño de las miniaturas de este sistema de colaboración. Si establece 0 entonces el tamaño establecido por defecto en la configuración maestro se utilizará. Así mismo, el cambio de este ajuste retroactivo no cambiará el tamaño de las miniaturas ya en el CS. Para esto tendrá que volver a guardar cada publicación para obtener el tamaño deseado a cambiar.'
  },
  'thumbnail.label' => {
    'lastUpdated' => '1208444020',
    'message' => 'La palabra &quot;Miniatura&quot;'
  },
  'timeSubmitted.human' => {
    'lastUpdated' => '1208444080',
    'message' => 'El tiempo en que se present&oacute; esta publicaci&oacute;n, en un formato legible por humanos.'
  },
  'timeUpdated.human' => {
    'lastUpdated' => '1208444204',
    'message' => 'El tiempo en que se public&oacute; la &uacute;ltima v&eacute;z, en un formato le&iacute;ble por humanos.'
  },
  'title' => {
    'lastUpdated' => '1252468638',
    'message' => 'Título'
  },
  'title.label' => {
    'lastUpdated' => '1208444221',
    'message' => 'La palabra &quot;T&iacute;tulo&quot;'
  },
  'tmplVar status' => {
    'lastUpdated' => '1208444237',
    'message' => 'la condici&oacute;n para esta publicaci&oacute;n'
  },
  'tmplVar thumbnail' => {
    'lastUpdated' => '1208444355',
    'message' => 'Si esta publicaci&oacute;n tiene archivos adjuntos y la URL de la miniatura de la primera imagen de archivo adjunto.'
  },
  'tmplVar url' => {
    'lastUpdated' => '1208444345',
    'message' => 'La URL para esta publicaci&oacute;n'
  },
  'transfer karma' => {
    'lastUpdated' => '1252468663',
    'message' => 'Transferir Karma'
  },
  'transferkarma.label' => {
    'lastUpdated' => '1257423601',
    'message' => 'La frase "Transferir Karma"'
  },
  'unarchive' => {
    'lastUpdated' => '1252468673',
    'message' => 'Desarchivar'
  },
  'unarchive all' => {
    'lastUpdated' => '1257423620',
    'message' => 'Desarchivar Todos'
  },
  'unarchive confirm' => {
    'lastUpdated' => '1257423657',
    'message' => '¿Está seguro? Todos los hilos que han pasado el umbral de archivado volverán a ser archivados.'
  },
  'unlock' => {
    'lastUpdated' => '1252468680',
    'message' => 'Desbloquear'
  },
  'unlock.label' => {
    'lastUpdated' => '1252468692',
    'message' => 'La palabra "Desbloquear"'
  },
  'unstick' => {
    'lastUpdated' => '1252468700',
    'message' => 'Despegar'
  },
  'unstick.label' => {
    'lastUpdated' => '1208444480',
    'message' => 'La palabra &quot;Despegar&quot;.'
  },
  'unsubscribe' => {
    'lastUpdated' => '1252468713',
    'message' => 'Desuscribirse'
  },
  'unsubscribe formEmail' => {
    'lastUpdated' => '1276808746',
    'message' => 'Un campo de texto con completado automático de dirección de correo.'
  },
  'unsubscribe formFooter' => {
    'lastUpdated' => '1276808762',
    'message' => 'Fragmento HTML para terminar el formulario de desuscripción.'
  },
  'unsubscribe formHeader' => {
    'lastUpdated' => '1276808776',
    'message' => 'Fragmento HTML para iniciar el formulario de desuscripción.'
  },
  'unsubscribe formMessage' => {
    'lastUpdated' => '1276808793',
    'message' => 'Mensajes para indicar al usuario éxitos o errores.'
  },
  'unsubscribe formSubmit' => {
    'lastUpdated' => '1276808810',
    'message' => 'El botón para enviar el formulario.'
  },
  'unsubscribe instructions' => {
    'lastUpdated' => '1276808834',
    'message' => 'Ingrese la dirección de correo del usuario que quiere desuscribirse.'
  },
  'unsubscribe template' => {
    'lastUpdated' => '1276808844',
    'message' => 'Plantilla para Desuscripción'
  },
  'unsubscribe template hoverHelp' => {
    'lastUpdated' => '1276808973',
    'message' => 'Indique la plantilla a utilizar para desplegar el formulario para desuscribirse de un Sistema de Colaboración o algún Hilo de Discusión.'
  },
  'unsubscribe.label' => {
    'lastUpdated' => '1208444753',
    'message' => 'La palabra &quot;Desinscribir&quot;'
  },
  'unsubscribe.url' => {
    'lastUpdated' => '1208444911',
    'message' => 'Una URL para el usuario actual desinscribirse&nbsp; de este Activo.'
  },
  'url' => {
    'lastUpdated' => '1208444925',
    'message' => 'URL'
  },
  'url.label' => {
    'lastUpdated' => '1208444940',
    'message' => 'La palabra &quot;URL&quot;.'
  },
  'use captcha hover help' => {
    'lastUpdated' => '1252468755',
    'message' => 'Establecer si los usuarios deben superar un CAPTCHA o no antes de poder enviar publicaciones o respuestas al Sistema de Colaboración.'
  },
  'use captcha label' => {
    'lastUpdated' => '1252468777',
    'message' => '¿CAPTCHA antes de publicar?'
  },
  'use preview' => {
    'lastUpdated' => '1252463115',
    'message' => '¿Utilizar vista previa?'
  },
  'use preview description' => {
    'lastUpdated' => '1252463189',
    'message' => 'Seleccione "Sí" para mostrar una vista previa de las Publicaciones a los usuarios antes de incorporarlas al Sistema de Colaboración. Una vez presentada la vista previa, la publicación puede ser editada o cancelada.'
  },
  'user' => {
    'lastUpdated' => '1252468857',
    'message' => 'Usuario'
  },
  'user defined 1' => {
    'lastUpdated' => '1253976739',
    'message' => 'Campo definido por el usuario #1'
  },
  'user defined 2' => {
    'lastUpdated' => '1253976725',
    'message' => 'Campo definido por el usuario #2'
  },
  'user defined 3' => {
    'lastUpdated' => '1253976749',
    'message' => 'Campo definido por el usuario #3'
  },
  'user defined 4' => {
    'lastUpdated' => '1253976759',
    'message' => 'Campo definido por el usuario #4'
  },
  'user defined 5' => {
    'lastUpdated' => '1253976768',
    'message' => 'Campo definido por el usuario #5'
  },
  'user.canPost' => {
    'lastUpdated' => '1208445705',
    'message' => 'Un condicional es cierto&nbsp; si el usuario actual puede a&ntilde;adir a esta publicai&oacute;n Colaboraci&oacute;n de Activos.'
  },
  'user.canStartThread' => {
    'lastUpdated' => '1257423682',
    'message' => 'Un condicional que indica si el usuario actual puede agregar Hilos a este Activo.'
  },
  'user.hasRead' => {
    'lastUpdated' => '1208446144',
    'message' => 'Un condicional que indica si un usuario ha le&iacute;do esta publicaci&oacute;n.'
  },
  'user.isModerator' => {
    'lastUpdated' => '1208445831',
    'message' => 'Un condicional es cierto que si el usuario actual es un moderador de este Activo.&nbsp;'
  },
  'user.isPoster' => {
    'lastUpdated' => '1208445939',
    'message' => 'Un condicional que indica que es cierto si el usuario actual ha presentado este Publicaci&oacute;n.'
  },
  'user.isSubscribed' => {
    'lastUpdated' => '1208446226',
    'message' => 'Un condicional es cierto&nbsp; si el usuario actual est&aacute; suscrito a este Colaboraci&oacute;n de Activos.'
  },
  'user.isVisitor' => {
    'lastUpdated' => '1208446332',
    'message' => 'Un condicional es cierto si la publicaci&oacute;n es de un visitante.'
  },
  'user.label' => {
    'lastUpdated' => '1208446353',
    'message' => 'La palabra &quot;Usuario&quot;.'
  },
  'userProfile.url' => {
    'lastUpdated' => '1208446411',
    'message' => 'La URL en el perfil del usuario que env&iacute;a esta publicaci&oacute;n.'
  },
  'views' => {
    'lastUpdated' => '1252468992',
    'message' => 'Vistas'
  },
  'views.label' => {
    'lastUpdated' => '1208446466',
    'message' => 'La palabra &quot;Vistas&quot;'
  },
  'visitor' => {
    'lastUpdated' => '1252469005',
    'message' => 'Nombre del Visitante'
  },
  'visitor cache timeout' => {
    'lastUpdated' => '1252469083',
    'message' => 'Tiempo Máximo en Cache'
  },
  'visitor cache timeout help' => {
    'lastUpdated' => '1252469069',
    'message' => 'Dado que todos los visitantes verán este activo de la misma manera, podemos activar caché para mejorar el rendimiento. ¿Cuánto tiempo debemos mantenerlo en cache?'
  },
  'visitorName.label' => {
    'lastUpdated' => '1208446584',
    'message' => 'La frase &quot;Nombre de Visitante&quot;.'
  },
  'webMaster' => {
    'lastUpdated' => '1252462585',
    'message' => 'Dirección de correo electrónico del responsable por los aspectos técnicos relacionados con esta fuente RSS (campo opcional)'
  },
  'who posts' => {
    'lastUpdated' => '1252462484',
    'message' => '¿Quien puede publicar?'
  },
  'who posts description' => {
    'lastUpdated' => '1252462509',
    'message' => 'Indique el grupo de usuarios que puede enviar nuevas publicaciones en este Activo.'
  },
  'who threads' => {
    'lastUpdated' => '1252462524',
    'message' => '¿Quién puede publicar respuestas?'
  },
  'who threads description' => {
    'lastUpdated' => '1252462551',
    'message' => '<div id="result_box" dir="ltr">Indique el grupo de usuarios que puede enviar respuestas a publicaciones existentes en este Activo.<br></div>'
  }
}
;

1;
